@@ -365,8 +365,10 @@ def _configure_dapr_app(_app, function, ctx: FunctionContext):
             if type == _DAPR_BINDINGS:
                 _app.binding(input.componentName)(function)
                 print("binding {}".format(input.componentName))
-            elif input.type == _DAPR_PUBSUB:
+            elif type == _DAPR_PUBSUB:
                 _app.subscribe(topic=input.uri, pubsub_name=input.componentName)(function)
+                key = _app._servicer._topic_map.keys()
+                _app._servicer._topic_map["{}:{}:{}".format(input.componentName,input.uri,input.uri)]=_app._servicer._topic_map.pop(list(key)[0])
                 print("sub topic {}, pubsub name {}".format(input.uri, input.componentName))
             else:
                 raise InvalidFuncContextInputType(
